PAULE
=====

.. image:: https://zenodo.org/badge/355606517.svg
   :target: https://zenodo.org/badge/latestdoi/355606517

Predictive Articulatory speech synthesis Utilizing Lexical Embeddings (PAULE) a
python frame work to plan control parameter trajectories for the VocalTractLab
simulator for a target acoustics or semantic embedding.


.. image:: https://raw.githubusercontent.com/quantling/paule/main/docs/figure/vtl_3d_vtl_midsagittal_cps_audio.png
  :width: 800
  :alt: A 3d vocal tract shape, a midsagittal slice, control parameter trajectories and a wave form.



Installation
------------

::

    pip install paule


Overview
--------

.. image:: https://raw.githubusercontent.com/quantling/paule/main/docs/figure/framework_simplified.png
  :width: 800
  :alt: Box and arrow overview of the PAULE model.

Example
-------

A minimal example can be found at https://raw.githubusercontent.com/quantling/paule/main/docs/examples/minimal_example.py


Cite
----

To cite the PAULE model use::

    @book{PAULEthesis,
      title     = "{P}redictive {A}rticulatory speech synthesis {U}tilizing {L}exical {E}mbeddings ({PAULE})",
      author    = "Sering, Konstantin",
      year      = 2023,
      publisher = "Universität Tübingen",
      address   = "Tübingen",
      doi       = {10.15496/publikation-90142}
    }

To cite the PAULE source code use the DOI 10.5281/zenodo.7252431
(https://zenodo.org/doi/10.5281/zenodo.7252431), if you want to cite the
software in general or the specific DOI on Zenodo.


Acknowledgements
----------------
This research was supported by an ERC advanced Grant (no. 742545), by the DfG grant 527671319 ("Komplexe Wörter im Kontext“), and the University of Tübingen.

